# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="page_setup.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import datetime
import six
import json

class PageSetup(object):
    """Represents the page setup properties of a section.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'bidi': 'bool',
        'border_always_in_front': 'bool',
        'border_applies_to': 'str',
        'border_distance_from': 'str',
        'bottom_margin': 'float',
        'different_first_page_header_footer': 'bool',
        'first_page_tray': 'int',
        'footer_distance': 'float',
        'gutter': 'float',
        'header_distance': 'float',
        'left_margin': 'float',
        'line_number_count_by': 'int',
        'line_number_distance_from_text': 'float',
        'line_number_restart_mode': 'str',
        'line_starting_number': 'int',
        'orientation': 'str',
        'other_pages_tray': 'int',
        'page_height': 'float',
        'page_number_style': 'str',
        'page_starting_number': 'int',
        'page_width': 'float',
        'paper_size': 'str',
        'restart_page_numbering': 'bool',
        'right_margin': 'float',
        'rtl_gutter': 'bool',
        'section_start': 'str',
        'suppress_endnotes': 'bool',
        'top_margin': 'float',
        'vertical_alignment': 'str'
    }

    attribute_map = {
        'link': 'Link',
        'bidi': 'Bidi',
        'border_always_in_front': 'BorderAlwaysInFront',
        'border_applies_to': 'BorderAppliesTo',
        'border_distance_from': 'BorderDistanceFrom',
        'bottom_margin': 'BottomMargin',
        'different_first_page_header_footer': 'DifferentFirstPageHeaderFooter',
        'first_page_tray': 'FirstPageTray',
        'footer_distance': 'FooterDistance',
        'gutter': 'Gutter',
        'header_distance': 'HeaderDistance',
        'left_margin': 'LeftMargin',
        'line_number_count_by': 'LineNumberCountBy',
        'line_number_distance_from_text': 'LineNumberDistanceFromText',
        'line_number_restart_mode': 'LineNumberRestartMode',
        'line_starting_number': 'LineStartingNumber',
        'orientation': 'Orientation',
        'other_pages_tray': 'OtherPagesTray',
        'page_height': 'PageHeight',
        'page_number_style': 'PageNumberStyle',
        'page_starting_number': 'PageStartingNumber',
        'page_width': 'PageWidth',
        'paper_size': 'PaperSize',
        'restart_page_numbering': 'RestartPageNumbering',
        'right_margin': 'RightMargin',
        'rtl_gutter': 'RtlGutter',
        'section_start': 'SectionStart',
        'suppress_endnotes': 'SuppressEndnotes',
        'top_margin': 'TopMargin',
        'vertical_alignment': 'VerticalAlignment'
    }

    def __init__(self, link=None, bidi=None, border_always_in_front=None, border_applies_to=None, border_distance_from=None, bottom_margin=None, different_first_page_header_footer=None, first_page_tray=None, footer_distance=None, gutter=None, header_distance=None, left_margin=None, line_number_count_by=None, line_number_distance_from_text=None, line_number_restart_mode=None, line_starting_number=None, orientation=None, other_pages_tray=None, page_height=None, page_number_style=None, page_starting_number=None, page_width=None, paper_size=None, restart_page_numbering=None, right_margin=None, rtl_gutter=None, section_start=None, suppress_endnotes=None, top_margin=None, vertical_alignment=None):  # noqa: E501
        """PageSetup - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._bidi = None
        self._border_always_in_front = None
        self._border_applies_to = None
        self._border_distance_from = None
        self._bottom_margin = None
        self._different_first_page_header_footer = None
        self._first_page_tray = None
        self._footer_distance = None
        self._gutter = None
        self._header_distance = None
        self._left_margin = None
        self._line_number_count_by = None
        self._line_number_distance_from_text = None
        self._line_number_restart_mode = None
        self._line_starting_number = None
        self._orientation = None
        self._other_pages_tray = None
        self._page_height = None
        self._page_number_style = None
        self._page_starting_number = None
        self._page_width = None
        self._paper_size = None
        self._restart_page_numbering = None
        self._right_margin = None
        self._rtl_gutter = None
        self._section_start = None
        self._suppress_endnotes = None
        self._top_margin = None
        self._vertical_alignment = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if bidi is not None:
            self.bidi = bidi
        if border_always_in_front is not None:
            self.border_always_in_front = border_always_in_front
        if border_applies_to is not None:
            self.border_applies_to = border_applies_to
        if border_distance_from is not None:
            self.border_distance_from = border_distance_from
        if bottom_margin is not None:
            self.bottom_margin = bottom_margin
        if different_first_page_header_footer is not None:
            self.different_first_page_header_footer = different_first_page_header_footer
        if first_page_tray is not None:
            self.first_page_tray = first_page_tray
        if footer_distance is not None:
            self.footer_distance = footer_distance
        if gutter is not None:
            self.gutter = gutter
        if header_distance is not None:
            self.header_distance = header_distance
        if left_margin is not None:
            self.left_margin = left_margin
        if line_number_count_by is not None:
            self.line_number_count_by = line_number_count_by
        if line_number_distance_from_text is not None:
            self.line_number_distance_from_text = line_number_distance_from_text
        if line_number_restart_mode is not None:
            self.line_number_restart_mode = line_number_restart_mode
        if line_starting_number is not None:
            self.line_starting_number = line_starting_number
        if orientation is not None:
            self.orientation = orientation
        if other_pages_tray is not None:
            self.other_pages_tray = other_pages_tray
        if page_height is not None:
            self.page_height = page_height
        if page_number_style is not None:
            self.page_number_style = page_number_style
        if page_starting_number is not None:
            self.page_starting_number = page_starting_number
        if page_width is not None:
            self.page_width = page_width
        if paper_size is not None:
            self.paper_size = paper_size
        if restart_page_numbering is not None:
            self.restart_page_numbering = restart_page_numbering
        if right_margin is not None:
            self.right_margin = right_margin
        if rtl_gutter is not None:
            self.rtl_gutter = rtl_gutter
        if section_start is not None:
            self.section_start = section_start
        if suppress_endnotes is not None:
            self.suppress_endnotes = suppress_endnotes
        if top_margin is not None:
            self.top_margin = top_margin
        if vertical_alignment is not None:
            self.vertical_alignment = vertical_alignment

    @property
    def link(self):
        """Gets the link of this PageSetup.  # noqa: E501

        Gets or sets the link to the document.  # noqa: E501

        :return: The link of this PageSetup.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this PageSetup.

        Gets or sets the link to the document.  # noqa: E501

        :param link: The link of this PageSetup.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def bidi(self):
        """Gets the bidi of this PageSetup.  # noqa: E501

        Gets or sets a value indicating whether this section contains bidirectional (complex scripts) text.  # noqa: E501

        :return: The bidi of this PageSetup.  # noqa: E501
        :rtype: bool
        """
        return self._bidi

    @bidi.setter
    def bidi(self, bidi):
        """Sets the bidi of this PageSetup.

        Gets or sets a value indicating whether this section contains bidirectional (complex scripts) text.  # noqa: E501

        :param bidi: The bidi of this PageSetup.  # noqa: E501
        :type: bool
        """
        self._bidi = bidi

    @property
    def border_always_in_front(self):
        """Gets the border_always_in_front of this PageSetup.  # noqa: E501

        Gets or sets a value indicating whether the page border is positioned relative to intersecting texts and objects.  # noqa: E501

        :return: The border_always_in_front of this PageSetup.  # noqa: E501
        :rtype: bool
        """
        return self._border_always_in_front

    @border_always_in_front.setter
    def border_always_in_front(self, border_always_in_front):
        """Sets the border_always_in_front of this PageSetup.

        Gets or sets a value indicating whether the page border is positioned relative to intersecting texts and objects.  # noqa: E501

        :param border_always_in_front: The border_always_in_front of this PageSetup.  # noqa: E501
        :type: bool
        """
        self._border_always_in_front = border_always_in_front

    @property
    def border_applies_to(self):
        """Gets the border_applies_to of this PageSetup.  # noqa: E501

        Gets or sets the option that controls which pages the page border is printed on.  # noqa: E501

        :return: The border_applies_to of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._border_applies_to

    @border_applies_to.setter
    def border_applies_to(self, border_applies_to):
        """Sets the border_applies_to of this PageSetup.

        Gets or sets the option that controls which pages the page border is printed on.  # noqa: E501

        :param border_applies_to: The border_applies_to of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["AllPages", "FirstPage", "OtherPages"]  # noqa: E501
        if not border_applies_to.isdigit():
            if border_applies_to not in allowed_values:
                raise ValueError(
                    "Invalid value for `border_applies_to` ({0}), must be one of {1}"  # noqa: E501
                    .format(border_applies_to, allowed_values))
            self._border_applies_to = border_applies_to
        else:
            self._border_applies_to = allowed_values[int(border_applies_to) if six.PY3 else long(border_applies_to)]

    @property
    def border_distance_from(self):
        """Gets the border_distance_from of this PageSetup.  # noqa: E501

        Gets or sets the value, that indicates whether the specified page border is measured from the edge of the page or from the text it surrounds.  # noqa: E501

        :return: The border_distance_from of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._border_distance_from

    @border_distance_from.setter
    def border_distance_from(self, border_distance_from):
        """Sets the border_distance_from of this PageSetup.

        Gets or sets the value, that indicates whether the specified page border is measured from the edge of the page or from the text it surrounds.  # noqa: E501

        :param border_distance_from: The border_distance_from of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["Text", "PageEdge"]  # noqa: E501
        if not border_distance_from.isdigit():
            if border_distance_from not in allowed_values:
                raise ValueError(
                    "Invalid value for `border_distance_from` ({0}), must be one of {1}"  # noqa: E501
                    .format(border_distance_from, allowed_values))
            self._border_distance_from = border_distance_from
        else:
            self._border_distance_from = allowed_values[int(border_distance_from) if six.PY3 else long(border_distance_from)]

    @property
    def bottom_margin(self):
        """Gets the bottom_margin of this PageSetup.  # noqa: E501

        Gets or sets the distance (in points) between the bottom edge of the page and the bottom boundary of the body text.  # noqa: E501

        :return: The bottom_margin of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._bottom_margin

    @bottom_margin.setter
    def bottom_margin(self, bottom_margin):
        """Sets the bottom_margin of this PageSetup.

        Gets or sets the distance (in points) between the bottom edge of the page and the bottom boundary of the body text.  # noqa: E501

        :param bottom_margin: The bottom_margin of this PageSetup.  # noqa: E501
        :type: float
        """
        self._bottom_margin = bottom_margin

    @property
    def different_first_page_header_footer(self):
        """Gets the different_first_page_header_footer of this PageSetup.  # noqa: E501

        Gets or sets a value indicating whether a different header or footer is used on the first page.  # noqa: E501

        :return: The different_first_page_header_footer of this PageSetup.  # noqa: E501
        :rtype: bool
        """
        return self._different_first_page_header_footer

    @different_first_page_header_footer.setter
    def different_first_page_header_footer(self, different_first_page_header_footer):
        """Sets the different_first_page_header_footer of this PageSetup.

        Gets or sets a value indicating whether a different header or footer is used on the first page.  # noqa: E501

        :param different_first_page_header_footer: The different_first_page_header_footer of this PageSetup.  # noqa: E501
        :type: bool
        """
        self._different_first_page_header_footer = different_first_page_header_footer

    @property
    def first_page_tray(self):
        """Gets the first_page_tray of this PageSetup.  # noqa: E501

        Gets or sets the paper tray (bin) to use for the first page of a section. The value is implementation (printer) specific.  # noqa: E501

        :return: The first_page_tray of this PageSetup.  # noqa: E501
        :rtype: int
        """
        return self._first_page_tray

    @first_page_tray.setter
    def first_page_tray(self, first_page_tray):
        """Sets the first_page_tray of this PageSetup.

        Gets or sets the paper tray (bin) to use for the first page of a section. The value is implementation (printer) specific.  # noqa: E501

        :param first_page_tray: The first_page_tray of this PageSetup.  # noqa: E501
        :type: int
        """
        self._first_page_tray = first_page_tray

    @property
    def footer_distance(self):
        """Gets the footer_distance of this PageSetup.  # noqa: E501

        Gets or sets the distance (in points) between the footer and the bottom of the page.  # noqa: E501

        :return: The footer_distance of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._footer_distance

    @footer_distance.setter
    def footer_distance(self, footer_distance):
        """Sets the footer_distance of this PageSetup.

        Gets or sets the distance (in points) between the footer and the bottom of the page.  # noqa: E501

        :param footer_distance: The footer_distance of this PageSetup.  # noqa: E501
        :type: float
        """
        self._footer_distance = footer_distance

    @property
    def gutter(self):
        """Gets the gutter of this PageSetup.  # noqa: E501

        Gets or sets the amount of extra space added to the margin for document binding.  # noqa: E501

        :return: The gutter of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._gutter

    @gutter.setter
    def gutter(self, gutter):
        """Sets the gutter of this PageSetup.

        Gets or sets the amount of extra space added to the margin for document binding.  # noqa: E501

        :param gutter: The gutter of this PageSetup.  # noqa: E501
        :type: float
        """
        self._gutter = gutter

    @property
    def header_distance(self):
        """Gets the header_distance of this PageSetup.  # noqa: E501

        Gets or sets the distance (in points) between the header and the top of the page.  # noqa: E501

        :return: The header_distance of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._header_distance

    @header_distance.setter
    def header_distance(self, header_distance):
        """Sets the header_distance of this PageSetup.

        Gets or sets the distance (in points) between the header and the top of the page.  # noqa: E501

        :param header_distance: The header_distance of this PageSetup.  # noqa: E501
        :type: float
        """
        self._header_distance = header_distance

    @property
    def left_margin(self):
        """Gets the left_margin of this PageSetup.  # noqa: E501

        Gets or sets the distance (in points) between the left edge of the page and the left boundary of the body text.  # noqa: E501

        :return: The left_margin of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._left_margin

    @left_margin.setter
    def left_margin(self, left_margin):
        """Sets the left_margin of this PageSetup.

        Gets or sets the distance (in points) between the left edge of the page and the left boundary of the body text.  # noqa: E501

        :param left_margin: The left_margin of this PageSetup.  # noqa: E501
        :type: float
        """
        self._left_margin = left_margin

    @property
    def line_number_count_by(self):
        """Gets the line_number_count_by of this PageSetup.  # noqa: E501

        Gets or sets the numeric increment for line numbers.  # noqa: E501

        :return: The line_number_count_by of this PageSetup.  # noqa: E501
        :rtype: int
        """
        return self._line_number_count_by

    @line_number_count_by.setter
    def line_number_count_by(self, line_number_count_by):
        """Sets the line_number_count_by of this PageSetup.

        Gets or sets the numeric increment for line numbers.  # noqa: E501

        :param line_number_count_by: The line_number_count_by of this PageSetup.  # noqa: E501
        :type: int
        """
        self._line_number_count_by = line_number_count_by

    @property
    def line_number_distance_from_text(self):
        """Gets the line_number_distance_from_text of this PageSetup.  # noqa: E501

        Gets or sets the distance between the right edge of line numbers and the left edge of the document.  # noqa: E501

        :return: The line_number_distance_from_text of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._line_number_distance_from_text

    @line_number_distance_from_text.setter
    def line_number_distance_from_text(self, line_number_distance_from_text):
        """Sets the line_number_distance_from_text of this PageSetup.

        Gets or sets the distance between the right edge of line numbers and the left edge of the document.  # noqa: E501

        :param line_number_distance_from_text: The line_number_distance_from_text of this PageSetup.  # noqa: E501
        :type: float
        """
        self._line_number_distance_from_text = line_number_distance_from_text

    @property
    def line_number_restart_mode(self):
        """Gets the line_number_restart_mode of this PageSetup.  # noqa: E501

        Gets or sets the way line numbering runs  that is, whether it starts over at the beginning of a new page or section or runs continuously.  # noqa: E501

        :return: The line_number_restart_mode of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._line_number_restart_mode

    @line_number_restart_mode.setter
    def line_number_restart_mode(self, line_number_restart_mode):
        """Sets the line_number_restart_mode of this PageSetup.

        Gets or sets the way line numbering runs  that is, whether it starts over at the beginning of a new page or section or runs continuously.  # noqa: E501

        :param line_number_restart_mode: The line_number_restart_mode of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["RestartPage", "RestartSection", "Continuous"]  # noqa: E501
        if not line_number_restart_mode.isdigit():
            if line_number_restart_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `line_number_restart_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(line_number_restart_mode, allowed_values))
            self._line_number_restart_mode = line_number_restart_mode
        else:
            self._line_number_restart_mode = allowed_values[int(line_number_restart_mode) if six.PY3 else long(line_number_restart_mode)]

    @property
    def line_starting_number(self):
        """Gets the line_starting_number of this PageSetup.  # noqa: E501

        Gets or sets the starting line number.  # noqa: E501

        :return: The line_starting_number of this PageSetup.  # noqa: E501
        :rtype: int
        """
        return self._line_starting_number

    @line_starting_number.setter
    def line_starting_number(self, line_starting_number):
        """Sets the line_starting_number of this PageSetup.

        Gets or sets the starting line number.  # noqa: E501

        :param line_starting_number: The line_starting_number of this PageSetup.  # noqa: E501
        :type: int
        """
        self._line_starting_number = line_starting_number

    @property
    def orientation(self):
        """Gets the orientation of this PageSetup.  # noqa: E501

        Gets or sets the orientation of the page.  # noqa: E501

        :return: The orientation of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._orientation

    @orientation.setter
    def orientation(self, orientation):
        """Sets the orientation of this PageSetup.

        Gets or sets the orientation of the page.  # noqa: E501

        :param orientation: The orientation of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["Portrait", "Landscape"]  # noqa: E501
        if not orientation.isdigit():
            if orientation not in allowed_values:
                raise ValueError(
                    "Invalid value for `orientation` ({0}), must be one of {1}"  # noqa: E501
                    .format(orientation, allowed_values))
            self._orientation = orientation
        else:
            self._orientation = allowed_values[int(orientation) if six.PY3 else long(orientation)]

    @property
    def other_pages_tray(self):
        """Gets the other_pages_tray of this PageSetup.  # noqa: E501

        Gets or sets the paper tray (bin) to be used for all but the first page of a section. The value is implementation (printer) specific.  # noqa: E501

        :return: The other_pages_tray of this PageSetup.  # noqa: E501
        :rtype: int
        """
        return self._other_pages_tray

    @other_pages_tray.setter
    def other_pages_tray(self, other_pages_tray):
        """Sets the other_pages_tray of this PageSetup.

        Gets or sets the paper tray (bin) to be used for all but the first page of a section. The value is implementation (printer) specific.  # noqa: E501

        :param other_pages_tray: The other_pages_tray of this PageSetup.  # noqa: E501
        :type: int
        """
        self._other_pages_tray = other_pages_tray

    @property
    def page_height(self):
        """Gets the page_height of this PageSetup.  # noqa: E501

        Gets or sets the height of the page in points.  # noqa: E501

        :return: The page_height of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._page_height

    @page_height.setter
    def page_height(self, page_height):
        """Sets the page_height of this PageSetup.

        Gets or sets the height of the page in points.  # noqa: E501

        :param page_height: The page_height of this PageSetup.  # noqa: E501
        :type: float
        """
        self._page_height = page_height

    @property
    def page_number_style(self):
        """Gets the page_number_style of this PageSetup.  # noqa: E501

        Gets or sets the page number format.  # noqa: E501

        :return: The page_number_style of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._page_number_style

    @page_number_style.setter
    def page_number_style(self, page_number_style):
        """Sets the page_number_style of this PageSetup.

        Gets or sets the page number format.  # noqa: E501

        :param page_number_style: The page_number_style of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["Arabic", "UppercaseRoman", "LowercaseRoman", "UppercaseLetter", "LowercaseLetter", "Ordinal", "Number", "OrdinalText", "Hex", "ChicagoManual", "Kanji", "KanjiDigit", "AiueoHalfWidth", "IrohaHalfWidth", "ArabicFullWidth", "ArabicHalfWidth", "KanjiTraditional", "KanjiTraditional2", "NumberInCircle", "DecimalFullWidth", "Aiueo", "Iroha", "LeadingZero", "Bullet", "Ganada", "Chosung", "GB1", "GB2", "GB3", "GB4", "Zodiac1", "Zodiac2", "Zodiac3", "TradChinNum1", "TradChinNum2", "TradChinNum3", "TradChinNum4", "SimpChinNum1", "SimpChinNum2", "SimpChinNum3", "SimpChinNum4", "HanjaRead", "HanjaReadDigit", "Hangul", "Hanja", "Hebrew1", "Arabic1", "Hebrew2", "Arabic2", "HindiLetter1", "HindiLetter2", "HindiArabic", "HindiCardinalText", "ThaiLetter", "ThaiArabic", "ThaiCardinalText", "VietCardinalText", "NumberInDash", "LowercaseRussian", "UppercaseRussian", "None", "Custom"]  # noqa: E501
        if not page_number_style.isdigit():
            if page_number_style not in allowed_values:
                raise ValueError(
                    "Invalid value for `page_number_style` ({0}), must be one of {1}"  # noqa: E501
                    .format(page_number_style, allowed_values))
            self._page_number_style = page_number_style
        else:
            self._page_number_style = allowed_values[int(page_number_style) if six.PY3 else long(page_number_style)]

    @property
    def page_starting_number(self):
        """Gets the page_starting_number of this PageSetup.  # noqa: E501

        Gets or sets the starting page number of the section.  # noqa: E501

        :return: The page_starting_number of this PageSetup.  # noqa: E501
        :rtype: int
        """
        return self._page_starting_number

    @page_starting_number.setter
    def page_starting_number(self, page_starting_number):
        """Sets the page_starting_number of this PageSetup.

        Gets or sets the starting page number of the section.  # noqa: E501

        :param page_starting_number: The page_starting_number of this PageSetup.  # noqa: E501
        :type: int
        """
        self._page_starting_number = page_starting_number

    @property
    def page_width(self):
        """Gets the page_width of this PageSetup.  # noqa: E501

        Gets or sets the width of the page in points.  # noqa: E501

        :return: The page_width of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._page_width

    @page_width.setter
    def page_width(self, page_width):
        """Sets the page_width of this PageSetup.

        Gets or sets the width of the page in points.  # noqa: E501

        :param page_width: The page_width of this PageSetup.  # noqa: E501
        :type: float
        """
        self._page_width = page_width

    @property
    def paper_size(self):
        """Gets the paper_size of this PageSetup.  # noqa: E501

        Gets or sets the paper size.  # noqa: E501

        :return: The paper_size of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._paper_size

    @paper_size.setter
    def paper_size(self, paper_size):
        """Sets the paper_size of this PageSetup.

        Gets or sets the paper size.  # noqa: E501

        :param paper_size: The paper_size of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["A3", "A4", "A5", "B4", "B5", "Executive", "Folio", "Ledger", "Legal", "Letter", "EnvelopeDL", "Quarto", "Statement", "Tabloid", "Paper10x14", "Paper11x17", "Number10Envelope", "Custom"]  # noqa: E501
        if not paper_size.isdigit():
            if paper_size not in allowed_values:
                raise ValueError(
                    "Invalid value for `paper_size` ({0}), must be one of {1}"  # noqa: E501
                    .format(paper_size, allowed_values))
            self._paper_size = paper_size
        else:
            self._paper_size = allowed_values[int(paper_size) if six.PY3 else long(paper_size)]

    @property
    def restart_page_numbering(self):
        """Gets the restart_page_numbering of this PageSetup.  # noqa: E501

        Gets or sets a value indicating whether page numbering restarts at the beginning of the section.  # noqa: E501

        :return: The restart_page_numbering of this PageSetup.  # noqa: E501
        :rtype: bool
        """
        return self._restart_page_numbering

    @restart_page_numbering.setter
    def restart_page_numbering(self, restart_page_numbering):
        """Sets the restart_page_numbering of this PageSetup.

        Gets or sets a value indicating whether page numbering restarts at the beginning of the section.  # noqa: E501

        :param restart_page_numbering: The restart_page_numbering of this PageSetup.  # noqa: E501
        :type: bool
        """
        self._restart_page_numbering = restart_page_numbering

    @property
    def right_margin(self):
        """Gets the right_margin of this PageSetup.  # noqa: E501

        Gets or sets the distance (in points) between the right edge of the page and the right boundary of the body text.  # noqa: E501

        :return: The right_margin of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._right_margin

    @right_margin.setter
    def right_margin(self, right_margin):
        """Sets the right_margin of this PageSetup.

        Gets or sets the distance (in points) between the right edge of the page and the right boundary of the body text.  # noqa: E501

        :param right_margin: The right_margin of this PageSetup.  # noqa: E501
        :type: float
        """
        self._right_margin = right_margin

    @property
    def rtl_gutter(self):
        """Gets the rtl_gutter of this PageSetup.  # noqa: E501

        Gets or sets a value indicating whether Microsoft Word uses gutters for the section based on a right-to-left language or a left-to-right language.  # noqa: E501

        :return: The rtl_gutter of this PageSetup.  # noqa: E501
        :rtype: bool
        """
        return self._rtl_gutter

    @rtl_gutter.setter
    def rtl_gutter(self, rtl_gutter):
        """Sets the rtl_gutter of this PageSetup.

        Gets or sets a value indicating whether Microsoft Word uses gutters for the section based on a right-to-left language or a left-to-right language.  # noqa: E501

        :param rtl_gutter: The rtl_gutter of this PageSetup.  # noqa: E501
        :type: bool
        """
        self._rtl_gutter = rtl_gutter

    @property
    def section_start(self):
        """Gets the section_start of this PageSetup.  # noqa: E501

        Gets or sets the type of section break for the specified object.  # noqa: E501

        :return: The section_start of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._section_start

    @section_start.setter
    def section_start(self, section_start):
        """Sets the section_start of this PageSetup.

        Gets or sets the type of section break for the specified object.  # noqa: E501

        :param section_start: The section_start of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["Continuous", "NewColumn", "NewPage", "EvenPage", "OddPage"]  # noqa: E501
        if not section_start.isdigit():
            if section_start not in allowed_values:
                raise ValueError(
                    "Invalid value for `section_start` ({0}), must be one of {1}"  # noqa: E501
                    .format(section_start, allowed_values))
            self._section_start = section_start
        else:
            self._section_start = allowed_values[int(section_start) if six.PY3 else long(section_start)]

    @property
    def suppress_endnotes(self):
        """Gets the suppress_endnotes of this PageSetup.  # noqa: E501

        Gets or sets a value indicating whether endnotes are printed at the end of the next section that doesn't suppress endnotes. Suppressed endnotes are printed before the endnotes in that section.  # noqa: E501

        :return: The suppress_endnotes of this PageSetup.  # noqa: E501
        :rtype: bool
        """
        return self._suppress_endnotes

    @suppress_endnotes.setter
    def suppress_endnotes(self, suppress_endnotes):
        """Sets the suppress_endnotes of this PageSetup.

        Gets or sets a value indicating whether endnotes are printed at the end of the next section that doesn't suppress endnotes. Suppressed endnotes are printed before the endnotes in that section.  # noqa: E501

        :param suppress_endnotes: The suppress_endnotes of this PageSetup.  # noqa: E501
        :type: bool
        """
        self._suppress_endnotes = suppress_endnotes

    @property
    def top_margin(self):
        """Gets the top_margin of this PageSetup.  # noqa: E501

        Gets or sets the distance (in points) between the top edge of the page and the top boundary of the body text.  # noqa: E501

        :return: The top_margin of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._top_margin

    @top_margin.setter
    def top_margin(self, top_margin):
        """Sets the top_margin of this PageSetup.

        Gets or sets the distance (in points) between the top edge of the page and the top boundary of the body text.  # noqa: E501

        :param top_margin: The top_margin of this PageSetup.  # noqa: E501
        :type: float
        """
        self._top_margin = top_margin

    @property
    def vertical_alignment(self):
        """Gets the vertical_alignment of this PageSetup.  # noqa: E501

        Gets or sets the vertical alignment of text on each page in the document.or section.  # noqa: E501

        :return: The vertical_alignment of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """Sets the vertical_alignment of this PageSetup.

        Gets or sets the vertical alignment of text on each page in the document.or section.  # noqa: E501

        :param vertical_alignment: The vertical_alignment of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["Top", "Center", "Justify", "Bottom"]  # noqa: E501
        if not vertical_alignment.isdigit():
            if vertical_alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `vertical_alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(vertical_alignment, allowed_values))
            self._vertical_alignment = vertical_alignment
        else:
            self._vertical_alignment = allowed_values[int(vertical_alignment) if six.PY3 else long(vertical_alignment)]


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageSetup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="outline_options_data.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import datetime
import six
import json

class OutlineOptionsData(object):
    """Container class for outline options.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bookmarks_outline_levels': 'list[BookmarksOutlineLevelData]',
        'create_missing_outline_levels': 'bool',
        'create_outlines_for_headings_in_tables': 'bool',
        'default_bookmarks_outline_level': 'int',
        'expanded_outline_levels': 'int',
        'headings_outline_levels': 'int'
    }

    attribute_map = {
        'bookmarks_outline_levels': 'BookmarksOutlineLevels',
        'create_missing_outline_levels': 'CreateMissingOutlineLevels',
        'create_outlines_for_headings_in_tables': 'CreateOutlinesForHeadingsInTables',
        'default_bookmarks_outline_level': 'DefaultBookmarksOutlineLevel',
        'expanded_outline_levels': 'ExpandedOutlineLevels',
        'headings_outline_levels': 'HeadingsOutlineLevels'
    }

    def __init__(self, bookmarks_outline_levels=None, create_missing_outline_levels=None, create_outlines_for_headings_in_tables=None, default_bookmarks_outline_level=None, expanded_outline_levels=None, headings_outline_levels=None):  # noqa: E501
        """OutlineOptionsData - a model defined in Swagger"""  # noqa: E501

        self._bookmarks_outline_levels = None
        self._create_missing_outline_levels = None
        self._create_outlines_for_headings_in_tables = None
        self._default_bookmarks_outline_level = None
        self._expanded_outline_levels = None
        self._headings_outline_levels = None
        self.discriminator = None

        if bookmarks_outline_levels is not None:
            self.bookmarks_outline_levels = bookmarks_outline_levels
        if create_missing_outline_levels is not None:
            self.create_missing_outline_levels = create_missing_outline_levels
        if create_outlines_for_headings_in_tables is not None:
            self.create_outlines_for_headings_in_tables = create_outlines_for_headings_in_tables
        if default_bookmarks_outline_level is not None:
            self.default_bookmarks_outline_level = default_bookmarks_outline_level
        if expanded_outline_levels is not None:
            self.expanded_outline_levels = expanded_outline_levels
        if headings_outline_levels is not None:
            self.headings_outline_levels = headings_outline_levels

    @property
    def bookmarks_outline_levels(self):
        """Gets the bookmarks_outline_levels of this OutlineOptionsData.  # noqa: E501

        Gets or sets the individual bookmarks outline level.  # noqa: E501

        :return: The bookmarks_outline_levels of this OutlineOptionsData.  # noqa: E501
        :rtype: list[BookmarksOutlineLevelData]
        """
        return self._bookmarks_outline_levels

    @bookmarks_outline_levels.setter
    def bookmarks_outline_levels(self, bookmarks_outline_levels):
        """Sets the bookmarks_outline_levels of this OutlineOptionsData.

        Gets or sets the individual bookmarks outline level.  # noqa: E501

        :param bookmarks_outline_levels: The bookmarks_outline_levels of this OutlineOptionsData.  # noqa: E501
        :type: list[BookmarksOutlineLevelData]
        """
        self._bookmarks_outline_levels = bookmarks_outline_levels

    @property
    def create_missing_outline_levels(self):
        """Gets the create_missing_outline_levels of this OutlineOptionsData.  # noqa: E501

        Gets or sets a value indicating whether to create missing outline levels when the document is exported. The default value is false.  # noqa: E501

        :return: The create_missing_outline_levels of this OutlineOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._create_missing_outline_levels

    @create_missing_outline_levels.setter
    def create_missing_outline_levels(self, create_missing_outline_levels):
        """Sets the create_missing_outline_levels of this OutlineOptionsData.

        Gets or sets a value indicating whether to create missing outline levels when the document is exported. The default value is false.  # noqa: E501

        :param create_missing_outline_levels: The create_missing_outline_levels of this OutlineOptionsData.  # noqa: E501
        :type: bool
        """
        self._create_missing_outline_levels = create_missing_outline_levels

    @property
    def create_outlines_for_headings_in_tables(self):
        """Gets the create_outlines_for_headings_in_tables of this OutlineOptionsData.  # noqa: E501

        Gets or sets a value indicating whether to create outlines for headings (paragraphs formatted with the Heading styles) inside tables.  # noqa: E501

        :return: The create_outlines_for_headings_in_tables of this OutlineOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._create_outlines_for_headings_in_tables

    @create_outlines_for_headings_in_tables.setter
    def create_outlines_for_headings_in_tables(self, create_outlines_for_headings_in_tables):
        """Sets the create_outlines_for_headings_in_tables of this OutlineOptionsData.

        Gets or sets a value indicating whether to create outlines for headings (paragraphs formatted with the Heading styles) inside tables.  # noqa: E501

        :param create_outlines_for_headings_in_tables: The create_outlines_for_headings_in_tables of this OutlineOptionsData.  # noqa: E501
        :type: bool
        """
        self._create_outlines_for_headings_in_tables = create_outlines_for_headings_in_tables

    @property
    def default_bookmarks_outline_level(self):
        """Gets the default_bookmarks_outline_level of this OutlineOptionsData.  # noqa: E501

        Gets or sets the default level in the document outline at which to display Word bookmarks.  # noqa: E501

        :return: The default_bookmarks_outline_level of this OutlineOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._default_bookmarks_outline_level

    @default_bookmarks_outline_level.setter
    def default_bookmarks_outline_level(self, default_bookmarks_outline_level):
        """Sets the default_bookmarks_outline_level of this OutlineOptionsData.

        Gets or sets the default level in the document outline at which to display Word bookmarks.  # noqa: E501

        :param default_bookmarks_outline_level: The default_bookmarks_outline_level of this OutlineOptionsData.  # noqa: E501
        :type: int
        """
        self._default_bookmarks_outline_level = default_bookmarks_outline_level

    @property
    def expanded_outline_levels(self):
        """Gets the expanded_outline_levels of this OutlineOptionsData.  # noqa: E501

        Gets or sets the number of levels in the document outline to show expanded when the file is viewed.  # noqa: E501

        :return: The expanded_outline_levels of this OutlineOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._expanded_outline_levels

    @expanded_outline_levels.setter
    def expanded_outline_levels(self, expanded_outline_levels):
        """Sets the expanded_outline_levels of this OutlineOptionsData.

        Gets or sets the number of levels in the document outline to show expanded when the file is viewed.  # noqa: E501

        :param expanded_outline_levels: The expanded_outline_levels of this OutlineOptionsData.  # noqa: E501
        :type: int
        """
        self._expanded_outline_levels = expanded_outline_levels

    @property
    def headings_outline_levels(self):
        """Gets the headings_outline_levels of this OutlineOptionsData.  # noqa: E501

        Gets or sets the number of levels of headings (paragraphs formatted with the Heading styles) to include in the document outline.  # noqa: E501

        :return: The headings_outline_levels of this OutlineOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._headings_outline_levels

    @headings_outline_levels.setter
    def headings_outline_levels(self, headings_outline_levels):
        """Sets the headings_outline_levels of this OutlineOptionsData.

        Gets or sets the number of levels of headings (paragraphs formatted with the Heading styles) to include in the document outline.  # noqa: E501

        :param headings_outline_levels: The headings_outline_levels of this OutlineOptionsData.  # noqa: E501
        :type: int
        """
        self._headings_outline_levels = headings_outline_levels


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OutlineOptionsData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="list_level_update.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import datetime
import six
import json

class ListLevelUpdate(object):
    """Represents a document list levels.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alignment': 'str',
        'is_legal': 'bool',
        'number_format': 'str',
        'number_position': 'float',
        'number_style': 'str',
        'restart_after_level': 'int',
        'start_at': 'int',
        'tab_position': 'float',
        'text_position': 'float',
        'trailing_character': 'str'
    }

    attribute_map = {
        'alignment': 'Alignment',
        'is_legal': 'IsLegal',
        'number_format': 'NumberFormat',
        'number_position': 'NumberPosition',
        'number_style': 'NumberStyle',
        'restart_after_level': 'RestartAfterLevel',
        'start_at': 'StartAt',
        'tab_position': 'TabPosition',
        'text_position': 'TextPosition',
        'trailing_character': 'TrailingCharacter'
    }

    def __init__(self, alignment=None, is_legal=None, number_format=None, number_position=None, number_style=None, restart_after_level=None, start_at=None, tab_position=None, text_position=None, trailing_character=None):  # noqa: E501
        """ListLevelUpdate - a model defined in Swagger"""  # noqa: E501

        self._alignment = None
        self._is_legal = None
        self._number_format = None
        self._number_position = None
        self._number_style = None
        self._restart_after_level = None
        self._start_at = None
        self._tab_position = None
        self._text_position = None
        self._trailing_character = None
        self.discriminator = None

        if alignment is not None:
            self.alignment = alignment
        if is_legal is not None:
            self.is_legal = is_legal
        if number_format is not None:
            self.number_format = number_format
        if number_position is not None:
            self.number_position = number_position
        if number_style is not None:
            self.number_style = number_style
        if restart_after_level is not None:
            self.restart_after_level = restart_after_level
        if start_at is not None:
            self.start_at = start_at
        if tab_position is not None:
            self.tab_position = tab_position
        if text_position is not None:
            self.text_position = text_position
        if trailing_character is not None:
            self.trailing_character = trailing_character

    @property
    def alignment(self):
        """Gets the alignment of this ListLevelUpdate.  # noqa: E501

        Gets or sets the justification of the actual number of the list item.  # noqa: E501

        :return: The alignment of this ListLevelUpdate.  # noqa: E501
        :rtype: str
        """
        return self._alignment

    @alignment.setter
    def alignment(self, alignment):
        """Sets the alignment of this ListLevelUpdate.

        Gets or sets the justification of the actual number of the list item.  # noqa: E501

        :param alignment: The alignment of this ListLevelUpdate.  # noqa: E501
        :type: str
        """
        allowed_values = ["Left", "Center", "Right"]  # noqa: E501
        if not alignment.isdigit():
            if alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(alignment, allowed_values))
            self._alignment = alignment
        else:
            self._alignment = allowed_values[int(alignment) if six.PY3 else long(alignment)]

    @property
    def is_legal(self):
        """Gets the is_legal of this ListLevelUpdate.  # noqa: E501

        Gets or sets a value indicating whether the level turns all inherited numbers to Arabic, false if it preserves their number style.  # noqa: E501

        :return: The is_legal of this ListLevelUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._is_legal

    @is_legal.setter
    def is_legal(self, is_legal):
        """Sets the is_legal of this ListLevelUpdate.

        Gets or sets a value indicating whether the level turns all inherited numbers to Arabic, false if it preserves their number style.  # noqa: E501

        :param is_legal: The is_legal of this ListLevelUpdate.  # noqa: E501
        :type: bool
        """
        self._is_legal = is_legal

    @property
    def number_format(self):
        """Gets the number_format of this ListLevelUpdate.  # noqa: E501

        Gets or sets the number format for the list level.  # noqa: E501

        :return: The number_format of this ListLevelUpdate.  # noqa: E501
        :rtype: str
        """
        return self._number_format

    @number_format.setter
    def number_format(self, number_format):
        """Sets the number_format of this ListLevelUpdate.

        Gets or sets the number format for the list level.  # noqa: E501

        :param number_format: The number_format of this ListLevelUpdate.  # noqa: E501
        :type: str
        """
        self._number_format = number_format

    @property
    def number_position(self):
        """Gets the number_position of this ListLevelUpdate.  # noqa: E501

        Gets or sets the position (in points) of the number or bullet for the list level.  # noqa: E501

        :return: The number_position of this ListLevelUpdate.  # noqa: E501
        :rtype: float
        """
        return self._number_position

    @number_position.setter
    def number_position(self, number_position):
        """Sets the number_position of this ListLevelUpdate.

        Gets or sets the position (in points) of the number or bullet for the list level.  # noqa: E501

        :param number_position: The number_position of this ListLevelUpdate.  # noqa: E501
        :type: float
        """
        self._number_position = number_position

    @property
    def number_style(self):
        """Gets the number_style of this ListLevelUpdate.  # noqa: E501

        Gets or sets the number style for this list level.  # noqa: E501

        :return: The number_style of this ListLevelUpdate.  # noqa: E501
        :rtype: str
        """
        return self._number_style

    @number_style.setter
    def number_style(self, number_style):
        """Sets the number_style of this ListLevelUpdate.

        Gets or sets the number style for this list level.  # noqa: E501

        :param number_style: The number_style of this ListLevelUpdate.  # noqa: E501
        :type: str
        """
        allowed_values = ["Arabic", "UppercaseRoman", "LowercaseRoman", "UppercaseLetter", "LowercaseLetter", "Ordinal", "Number", "OrdinalText", "Hex", "ChicagoManual", "Kanji", "KanjiDigit", "AiueoHalfWidth", "IrohaHalfWidth", "ArabicFullWidth", "ArabicHalfWidth", "KanjiTraditional", "KanjiTraditional2", "NumberInCircle", "DecimalFullWidth", "Aiueo", "Iroha", "LeadingZero", "Bullet", "Ganada", "Chosung", "GB1", "GB2", "GB3", "GB4", "Zodiac1", "Zodiac2", "Zodiac3", "TradChinNum1", "TradChinNum2", "TradChinNum3", "TradChinNum4", "SimpChinNum1", "SimpChinNum2", "SimpChinNum3", "SimpChinNum4", "HanjaRead", "HanjaReadDigit", "Hangul", "Hanja", "Hebrew1", "Arabic1", "Hebrew2", "Arabic2", "HindiLetter1", "HindiLetter2", "HindiArabic", "HindiCardinalText", "ThaiLetter", "ThaiArabic", "ThaiCardinalText", "VietCardinalText", "NumberInDash", "LowercaseRussian", "UppercaseRussian", "None", "Custom"]  # noqa: E501
        if not number_style.isdigit():
            if number_style not in allowed_values:
                raise ValueError(
                    "Invalid value for `number_style` ({0}), must be one of {1}"  # noqa: E501
                    .format(number_style, allowed_values))
            self._number_style = number_style
        else:
            self._number_style = allowed_values[int(number_style) if six.PY3 else long(number_style)]

    @property
    def restart_after_level(self):
        """Gets the restart_after_level of this ListLevelUpdate.  # noqa: E501

        Gets or sets the list level that must appear before the specified list level restarts numbering.  # noqa: E501

        :return: The restart_after_level of this ListLevelUpdate.  # noqa: E501
        :rtype: int
        """
        return self._restart_after_level

    @restart_after_level.setter
    def restart_after_level(self, restart_after_level):
        """Sets the restart_after_level of this ListLevelUpdate.

        Gets or sets the list level that must appear before the specified list level restarts numbering.  # noqa: E501

        :param restart_after_level: The restart_after_level of this ListLevelUpdate.  # noqa: E501
        :type: int
        """
        self._restart_after_level = restart_after_level

    @property
    def start_at(self):
        """Gets the start_at of this ListLevelUpdate.  # noqa: E501

        Gets or sets the starting number for this list level.  # noqa: E501

        :return: The start_at of this ListLevelUpdate.  # noqa: E501
        :rtype: int
        """
        return self._start_at

    @start_at.setter
    def start_at(self, start_at):
        """Sets the start_at of this ListLevelUpdate.

        Gets or sets the starting number for this list level.  # noqa: E501

        :param start_at: The start_at of this ListLevelUpdate.  # noqa: E501
        :type: int
        """
        self._start_at = start_at

    @property
    def tab_position(self):
        """Gets the tab_position of this ListLevelUpdate.  # noqa: E501

        Gets or sets the tab position (in points) for the list level.  # noqa: E501

        :return: The tab_position of this ListLevelUpdate.  # noqa: E501
        :rtype: float
        """
        return self._tab_position

    @tab_position.setter
    def tab_position(self, tab_position):
        """Sets the tab_position of this ListLevelUpdate.

        Gets or sets the tab position (in points) for the list level.  # noqa: E501

        :param tab_position: The tab_position of this ListLevelUpdate.  # noqa: E501
        :type: float
        """
        self._tab_position = tab_position

    @property
    def text_position(self):
        """Gets the text_position of this ListLevelUpdate.  # noqa: E501

        Gets or sets the position (in points) for the second line of wrapping text for the list level.  # noqa: E501

        :return: The text_position of this ListLevelUpdate.  # noqa: E501
        :rtype: float
        """
        return self._text_position

    @text_position.setter
    def text_position(self, text_position):
        """Sets the text_position of this ListLevelUpdate.

        Gets or sets the position (in points) for the second line of wrapping text for the list level.  # noqa: E501

        :param text_position: The text_position of this ListLevelUpdate.  # noqa: E501
        :type: float
        """
        self._text_position = text_position

    @property
    def trailing_character(self):
        """Gets the trailing_character of this ListLevelUpdate.  # noqa: E501

        Gets or sets the character to be inserted after the number for the list level.  # noqa: E501

        :return: The trailing_character of this ListLevelUpdate.  # noqa: E501
        :rtype: str
        """
        return self._trailing_character

    @trailing_character.setter
    def trailing_character(self, trailing_character):
        """Sets the trailing_character of this ListLevelUpdate.

        Gets or sets the character to be inserted after the number for the list level.  # noqa: E501

        :param trailing_character: The trailing_character of this ListLevelUpdate.  # noqa: E501
        :type: str
        """
        allowed_values = ["Tab", "Space", "Nothing"]  # noqa: E501
        if not trailing_character.isdigit():
            if trailing_character not in allowed_values:
                raise ValueError(
                    "Invalid value for `trailing_character` ({0}), must be one of {1}"  # noqa: E501
                    .format(trailing_character, allowed_values))
            self._trailing_character = trailing_character
        else:
            self._trailing_character = allowed_values[int(trailing_character) if six.PY3 else long(trailing_character)]


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListLevelUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="table_cell_format.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import datetime
import six
import json

class TableCellFormat(object):
    """DTO container with all formatting for a table row.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'bottom_padding': 'float',
        'fit_text': 'bool',
        'horizontal_merge': 'str',
        'left_padding': 'float',
        'orientation': 'str',
        'preferred_width': 'PreferredWidth',
        'right_padding': 'float',
        'top_padding': 'float',
        'vertical_alignment': 'str',
        'vertical_merge': 'str',
        'width': 'float',
        'wrap_text': 'bool'
    }

    attribute_map = {
        'link': 'Link',
        'bottom_padding': 'BottomPadding',
        'fit_text': 'FitText',
        'horizontal_merge': 'HorizontalMerge',
        'left_padding': 'LeftPadding',
        'orientation': 'Orientation',
        'preferred_width': 'PreferredWidth',
        'right_padding': 'RightPadding',
        'top_padding': 'TopPadding',
        'vertical_alignment': 'VerticalAlignment',
        'vertical_merge': 'VerticalMerge',
        'width': 'Width',
        'wrap_text': 'WrapText'
    }

    def __init__(self, link=None, bottom_padding=None, fit_text=None, horizontal_merge=None, left_padding=None, orientation=None, preferred_width=None, right_padding=None, top_padding=None, vertical_alignment=None, vertical_merge=None, width=None, wrap_text=None):  # noqa: E501
        """TableCellFormat - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._bottom_padding = None
        self._fit_text = None
        self._horizontal_merge = None
        self._left_padding = None
        self._orientation = None
        self._preferred_width = None
        self._right_padding = None
        self._top_padding = None
        self._vertical_alignment = None
        self._vertical_merge = None
        self._width = None
        self._wrap_text = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if bottom_padding is not None:
            self.bottom_padding = bottom_padding
        if fit_text is not None:
            self.fit_text = fit_text
        if horizontal_merge is not None:
            self.horizontal_merge = horizontal_merge
        if left_padding is not None:
            self.left_padding = left_padding
        if orientation is not None:
            self.orientation = orientation
        if preferred_width is not None:
            self.preferred_width = preferred_width
        if right_padding is not None:
            self.right_padding = right_padding
        if top_padding is not None:
            self.top_padding = top_padding
        if vertical_alignment is not None:
            self.vertical_alignment = vertical_alignment
        if vertical_merge is not None:
            self.vertical_merge = vertical_merge
        if width is not None:
            self.width = width
        if wrap_text is not None:
            self.wrap_text = wrap_text

    @property
    def link(self):
        """Gets the link of this TableCellFormat.  # noqa: E501

        Gets or sets the link to the document.  # noqa: E501

        :return: The link of this TableCellFormat.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this TableCellFormat.

        Gets or sets the link to the document.  # noqa: E501

        :param link: The link of this TableCellFormat.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def bottom_padding(self):
        """Gets the bottom_padding of this TableCellFormat.  # noqa: E501

        Gets or sets the amount of space (in points) to add below the contents of the cell.  # noqa: E501

        :return: The bottom_padding of this TableCellFormat.  # noqa: E501
        :rtype: float
        """
        return self._bottom_padding

    @bottom_padding.setter
    def bottom_padding(self, bottom_padding):
        """Sets the bottom_padding of this TableCellFormat.

        Gets or sets the amount of space (in points) to add below the contents of the cell.  # noqa: E501

        :param bottom_padding: The bottom_padding of this TableCellFormat.  # noqa: E501
        :type: float
        """
        self._bottom_padding = bottom_padding

    @property
    def fit_text(self):
        """Gets the fit_text of this TableCellFormat.  # noqa: E501

        Gets or sets a value indicating whether to fit text in the cell, compress each paragraph to the width of the cell.  # noqa: E501

        :return: The fit_text of this TableCellFormat.  # noqa: E501
        :rtype: bool
        """
        return self._fit_text

    @fit_text.setter
    def fit_text(self, fit_text):
        """Sets the fit_text of this TableCellFormat.

        Gets or sets a value indicating whether to fit text in the cell, compress each paragraph to the width of the cell.  # noqa: E501

        :param fit_text: The fit_text of this TableCellFormat.  # noqa: E501
        :type: bool
        """
        self._fit_text = fit_text

    @property
    def horizontal_merge(self):
        """Gets the horizontal_merge of this TableCellFormat.  # noqa: E501

        Gets or sets the option that controls how the cell is merged horizontally with other cells in the row.  # noqa: E501

        :return: The horizontal_merge of this TableCellFormat.  # noqa: E501
        :rtype: str
        """
        return self._horizontal_merge

    @horizontal_merge.setter
    def horizontal_merge(self, horizontal_merge):
        """Sets the horizontal_merge of this TableCellFormat.

        Gets or sets the option that controls how the cell is merged horizontally with other cells in the row.  # noqa: E501

        :param horizontal_merge: The horizontal_merge of this TableCellFormat.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "First", "Previous"]  # noqa: E501
        if not horizontal_merge.isdigit():
            if horizontal_merge not in allowed_values:
                raise ValueError(
                    "Invalid value for `horizontal_merge` ({0}), must be one of {1}"  # noqa: E501
                    .format(horizontal_merge, allowed_values))
            self._horizontal_merge = horizontal_merge
        else:
            self._horizontal_merge = allowed_values[int(horizontal_merge) if six.PY3 else long(horizontal_merge)]

    @property
    def left_padding(self):
        """Gets the left_padding of this TableCellFormat.  # noqa: E501

        Gets or sets the amount of space (in points) to add to the left of the contents of the cell.  # noqa: E501

        :return: The left_padding of this TableCellFormat.  # noqa: E501
        :rtype: float
        """
        return self._left_padding

    @left_padding.setter
    def left_padding(self, left_padding):
        """Sets the left_padding of this TableCellFormat.

        Gets or sets the amount of space (in points) to add to the left of the contents of the cell.  # noqa: E501

        :param left_padding: The left_padding of this TableCellFormat.  # noqa: E501
        :type: float
        """
        self._left_padding = left_padding

    @property
    def orientation(self):
        """Gets the orientation of this TableCellFormat.  # noqa: E501

        Gets or sets the orientation of text in a table cell.  # noqa: E501

        :return: The orientation of this TableCellFormat.  # noqa: E501
        :rtype: str
        """
        return self._orientation

    @orientation.setter
    def orientation(self, orientation):
        """Sets the orientation of this TableCellFormat.

        Gets or sets the orientation of text in a table cell.  # noqa: E501

        :param orientation: The orientation of this TableCellFormat.  # noqa: E501
        :type: str
        """
        allowed_values = ["Horizontal", "Downward", "Upward", "HorizontalRotatedFarEast", "VerticalFarEast", "VerticalRotatedFarEast"]  # noqa: E501
        if not orientation.isdigit():
            if orientation not in allowed_values:
                raise ValueError(
                    "Invalid value for `orientation` ({0}), must be one of {1}"  # noqa: E501
                    .format(orientation, allowed_values))
            self._orientation = orientation
        else:
            self._orientation = allowed_values[int(orientation) if six.PY3 else long(orientation)]

    @property
    def preferred_width(self):
        """Gets the preferred_width of this TableCellFormat.  # noqa: E501

        Gets or sets the preferred width of the cell.  # noqa: E501

        :return: The preferred_width of this TableCellFormat.  # noqa: E501
        :rtype: PreferredWidth
        """
        return self._preferred_width

    @preferred_width.setter
    def preferred_width(self, preferred_width):
        """Sets the preferred_width of this TableCellFormat.

        Gets or sets the preferred width of the cell.  # noqa: E501

        :param preferred_width: The preferred_width of this TableCellFormat.  # noqa: E501
        :type: PreferredWidth
        """
        self._preferred_width = preferred_width

    @property
    def right_padding(self):
        """Gets the right_padding of this TableCellFormat.  # noqa: E501

        Gets or sets the amount of space (in points) to add to the right of the contents of the cell.  # noqa: E501

        :return: The right_padding of this TableCellFormat.  # noqa: E501
        :rtype: float
        """
        return self._right_padding

    @right_padding.setter
    def right_padding(self, right_padding):
        """Sets the right_padding of this TableCellFormat.

        Gets or sets the amount of space (in points) to add to the right of the contents of the cell.  # noqa: E501

        :param right_padding: The right_padding of this TableCellFormat.  # noqa: E501
        :type: float
        """
        self._right_padding = right_padding

    @property
    def top_padding(self):
        """Gets the top_padding of this TableCellFormat.  # noqa: E501

        Gets or sets the amount of space (in points) to add above the contents of the cell.  # noqa: E501

        :return: The top_padding of this TableCellFormat.  # noqa: E501
        :rtype: float
        """
        return self._top_padding

    @top_padding.setter
    def top_padding(self, top_padding):
        """Sets the top_padding of this TableCellFormat.

        Gets or sets the amount of space (in points) to add above the contents of the cell.  # noqa: E501

        :param top_padding: The top_padding of this TableCellFormat.  # noqa: E501
        :type: float
        """
        self._top_padding = top_padding

    @property
    def vertical_alignment(self):
        """Gets the vertical_alignment of this TableCellFormat.  # noqa: E501

        Gets or sets the vertical alignment of text in the cell.  # noqa: E501

        :return: The vertical_alignment of this TableCellFormat.  # noqa: E501
        :rtype: str
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """Sets the vertical_alignment of this TableCellFormat.

        Gets or sets the vertical alignment of text in the cell.  # noqa: E501

        :param vertical_alignment: The vertical_alignment of this TableCellFormat.  # noqa: E501
        :type: str
        """
        allowed_values = ["Top", "Center", "Bottom"]  # noqa: E501
        if not vertical_alignment.isdigit():
            if vertical_alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `vertical_alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(vertical_alignment, allowed_values))
            self._vertical_alignment = vertical_alignment
        else:
            self._vertical_alignment = allowed_values[int(vertical_alignment) if six.PY3 else long(vertical_alignment)]

    @property
    def vertical_merge(self):
        """Gets the vertical_merge of this TableCellFormat.  # noqa: E501

        Gets or sets the option that controls how the cell is merged with other cells vertically.  # noqa: E501

        :return: The vertical_merge of this TableCellFormat.  # noqa: E501
        :rtype: str
        """
        return self._vertical_merge

    @vertical_merge.setter
    def vertical_merge(self, vertical_merge):
        """Sets the vertical_merge of this TableCellFormat.

        Gets or sets the option that controls how the cell is merged with other cells vertically.  # noqa: E501

        :param vertical_merge: The vertical_merge of this TableCellFormat.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "First", "Previous"]  # noqa: E501
        if not vertical_merge.isdigit():
            if vertical_merge not in allowed_values:
                raise ValueError(
                    "Invalid value for `vertical_merge` ({0}), must be one of {1}"  # noqa: E501
                    .format(vertical_merge, allowed_values))
            self._vertical_merge = vertical_merge
        else:
            self._vertical_merge = allowed_values[int(vertical_merge) if six.PY3 else long(vertical_merge)]

    @property
    def width(self):
        """Gets the width of this TableCellFormat.  # noqa: E501

        Gets or sets the width of the cell in points.  # noqa: E501

        :return: The width of this TableCellFormat.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this TableCellFormat.

        Gets or sets the width of the cell in points.  # noqa: E501

        :param width: The width of this TableCellFormat.  # noqa: E501
        :type: float
        """
        self._width = width

    @property
    def wrap_text(self):
        """Gets the wrap_text of this TableCellFormat.  # noqa: E501

        Gets or sets a value indicating whether to wrap text in the cell.  # noqa: E501

        :return: The wrap_text of this TableCellFormat.  # noqa: E501
        :rtype: bool
        """
        return self._wrap_text

    @wrap_text.setter
    def wrap_text(self, wrap_text):
        """Sets the wrap_text of this TableCellFormat.

        Gets or sets a value indicating whether to wrap text in the cell.  # noqa: E501

        :param wrap_text: The wrap_text of this TableCellFormat.  # noqa: E501
        :type: bool
        """
        self._wrap_text = wrap_text


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TableCellFormat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


from asposewordscloud.models.responses.accept_all_revisions_online_response import AcceptAllRevisionsOnlineResponse
from asposewordscloud.models.responses.append_document_online_response import AppendDocumentOnlineResponse
from asposewordscloud.models.responses.apply_style_to_document_element_online_response import ApplyStyleToDocumentElementOnlineResponse
from asposewordscloud.models.responses.compare_document_online_response import CompareDocumentOnlineResponse
from asposewordscloud.models.responses.compress_document_online_response import CompressDocumentOnlineResponse
from asposewordscloud.models.responses.copy_style_online_response import CopyStyleOnlineResponse
from asposewordscloud.models.responses.create_or_update_document_property_online_response import CreateOrUpdateDocumentPropertyOnlineResponse
from asposewordscloud.models.responses.delete_all_paragraph_tab_stops_online_response import DeleteAllParagraphTabStopsOnlineResponse
from asposewordscloud.models.responses.delete_border_online_response import DeleteBorderOnlineResponse
from asposewordscloud.models.responses.delete_borders_online_response import DeleteBordersOnlineResponse
from asposewordscloud.models.responses.delete_paragraph_list_format_online_response import DeleteParagraphListFormatOnlineResponse
from asposewordscloud.models.responses.delete_paragraph_tab_stop_online_response import DeleteParagraphTabStopOnlineResponse
from asposewordscloud.models.responses.delete_watermark_online_response import DeleteWatermarkOnlineResponse
from asposewordscloud.models.responses.insert_bookmark_online_response import InsertBookmarkOnlineResponse
from asposewordscloud.models.responses.insert_comment_online_response import InsertCommentOnlineResponse
from asposewordscloud.models.responses.insert_custom_xml_part_online_response import InsertCustomXmlPartOnlineResponse
from asposewordscloud.models.responses.insert_drawing_object_online_response import InsertDrawingObjectOnlineResponse
from asposewordscloud.models.responses.insert_field_online_response import InsertFieldOnlineResponse
from asposewordscloud.models.responses.insert_footnote_online_response import InsertFootnoteOnlineResponse
from asposewordscloud.models.responses.insert_form_field_online_response import InsertFormFieldOnlineResponse
from asposewordscloud.models.responses.insert_header_footer_online_response import InsertHeaderFooterOnlineResponse
from asposewordscloud.models.responses.insert_list_online_response import InsertListOnlineResponse
from asposewordscloud.models.responses.insert_or_update_paragraph_tab_stop_online_response import InsertOrUpdateParagraphTabStopOnlineResponse
from asposewordscloud.models.responses.insert_page_numbers_online_response import InsertPageNumbersOnlineResponse
from asposewordscloud.models.responses.insert_paragraph_online_response import InsertParagraphOnlineResponse
from asposewordscloud.models.responses.insert_run_online_response import InsertRunOnlineResponse
from asposewordscloud.models.responses.insert_structured_document_tag_online_response import InsertStructuredDocumentTagOnlineResponse
from asposewordscloud.models.responses.insert_style_online_response import InsertStyleOnlineResponse
from asposewordscloud.models.responses.insert_table_cell_online_response import InsertTableCellOnlineResponse
from asposewordscloud.models.responses.insert_table_online_response import InsertTableOnlineResponse
from asposewordscloud.models.responses.insert_table_row_online_response import InsertTableRowOnlineResponse
from asposewordscloud.models.responses.insert_watermark_image_online_response import InsertWatermarkImageOnlineResponse
from asposewordscloud.models.responses.insert_watermark_text_online_response import InsertWatermarkTextOnlineResponse
from asposewordscloud.models.responses.protect_document_online_response import ProtectDocumentOnlineResponse
from asposewordscloud.models.responses.reject_all_revisions_online_response import RejectAllRevisionsOnlineResponse
from asposewordscloud.models.responses.remove_range_online_response import RemoveRangeOnlineResponse
from asposewordscloud.models.responses.replace_text_online_response import ReplaceTextOnlineResponse
from asposewordscloud.models.responses.replace_with_text_online_response import ReplaceWithTextOnlineResponse
from asposewordscloud.models.responses.save_as_online_response import SaveAsOnlineResponse
from asposewordscloud.models.responses.save_as_range_online_response import SaveAsRangeOnlineResponse
from asposewordscloud.models.responses.save_as_tiff_online_response import SaveAsTiffOnlineResponse
from asposewordscloud.models.responses.split_document_online_response import SplitDocumentOnlineResponse
from asposewordscloud.models.responses.unprotect_document_online_response import UnprotectDocumentOnlineResponse
from asposewordscloud.models.responses.update_bookmark_online_response import UpdateBookmarkOnlineResponse
from asposewordscloud.models.responses.update_border_online_response import UpdateBorderOnlineResponse
from asposewordscloud.models.responses.update_comment_online_response import UpdateCommentOnlineResponse
from asposewordscloud.models.responses.update_custom_xml_part_online_response import UpdateCustomXmlPartOnlineResponse
from asposewordscloud.models.responses.update_drawing_object_online_response import UpdateDrawingObjectOnlineResponse
from asposewordscloud.models.responses.update_field_online_response import UpdateFieldOnlineResponse
from asposewordscloud.models.responses.update_fields_online_response import UpdateFieldsOnlineResponse
from asposewordscloud.models.responses.update_footnote_online_response import UpdateFootnoteOnlineResponse
from asposewordscloud.models.responses.update_form_field_online_response import UpdateFormFieldOnlineResponse
from asposewordscloud.models.responses.update_list_level_online_response import UpdateListLevelOnlineResponse
from asposewordscloud.models.responses.update_list_online_response import UpdateListOnlineResponse
from asposewordscloud.models.responses.update_paragraph_format_online_response import UpdateParagraphFormatOnlineResponse
from asposewordscloud.models.responses.update_paragraph_list_format_online_response import UpdateParagraphListFormatOnlineResponse
from asposewordscloud.models.responses.update_run_font_online_response import UpdateRunFontOnlineResponse
from asposewordscloud.models.responses.update_run_online_response import UpdateRunOnlineResponse
from asposewordscloud.models.responses.update_section_page_setup_online_response import UpdateSectionPageSetupOnlineResponse
from asposewordscloud.models.responses.update_structured_document_tag_online_response import UpdateStructuredDocumentTagOnlineResponse
from asposewordscloud.models.responses.update_style_online_response import UpdateStyleOnlineResponse
from asposewordscloud.models.responses.update_table_cell_format_online_response import UpdateTableCellFormatOnlineResponse
from asposewordscloud.models.responses.update_table_properties_online_response import UpdateTablePropertiesOnlineResponse
from asposewordscloud.models.responses.update_table_row_format_online_response import UpdateTableRowFormatOnlineResponse



# coding: utf-8

"""
    Aspose.Words for Cloud API Reference

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 23.3

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "aspose-words-cloud"
VERSION = "23.3.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.16", "six >= 1.10", "requests-toolbelt >= 0.9.1", "certifi", "python-dateutil"]

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), 'r') as f:
    long_description = f.read()

setup(
    name=NAME,
    version=VERSION,
    description="Python Cloud SDK wraps Aspose.Words Cloud API so you could seamlessly integrate Microsoft Word file generation, manipulation, conversion & inspection features into your own python applications.",
    author='Yaroslaw Ekimov',
    author_email="yaroslaw.ekimov@aspose.com",
    url="https://github.com/aspose-words-cloud/aspose-words-cloud-python",
	classifiers=[
		'Development Status :: 5 - Production/Stable',
		'Intended Audience :: Developers',
        'Topic :: Office/Business :: Office Suites',
		'Topic :: Software Development :: Libraries',
		'License :: OSI Approved :: MIT License',
		'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
	],
    keywords=["office", "convert", "word", "pdf", "docx", "html", "rtf", "png", "jpg", "split", "merge", "edit", "word to pdf",
    "pdf to word", "docx to pdf", "pdf to docx", "word to html", "html to word", "reporting", "mailmerge", "statistics",
    "watermark", "fields", "generate", "create", "report", "table", "paragraph", "images", "text", "generator", "creator", "maker"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=long_description,
    long_description_content_type="text/markdown"
)



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="test_batch.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from urllib3 import request
import asposewordscloud.models
import os
import asposewordscloud.models.requests
from test.base_test_context import BaseTestContext


class TestBatch(BaseTestContext):

    test_folder = 'DocumentElements/Bookmarks'

    #
    # Test for batch request
    #
    def test_batch(self):
        filename = 'test_multi_pages.docx'
        remote_name = 'TestBatchParagraphs.docx'
        file = open(os.path.join(self.local_test_folder, self.local_common_folder, filename), 'rb')
        remote_path = os.path.join(self.remote_test_folder, self.test_folder, remote_name)
        remote_folder = os.path.join(self.remote_test_folder, self.test_folder)
        paragraph = asposewordscloud.models.ParagraphInsert(text="This is a new paragraph for your document")
        request0 = asposewordscloud.models.requests.UploadFileRequest(file, remote_path)
        request1 = asposewordscloud.models.requests.GetParagraphsRequest(name=remote_name, node_path="sections/0", folder=remote_folder)
        request2 = asposewordscloud.models.requests.GetParagraphRequest(name=remote_name, index=0, node_path="sections/0", folder=remote_folder)
        request3 = asposewordscloud.models.requests.InsertParagraphRequest(name=remote_name, paragraph=paragraph, node_path="sections/0", folder=remote_folder)
        request4 = asposewordscloud.models.requests.DeleteParagraphRequest(name=remote_name, index=0, node_path="", folder=remote_folder)

        reportingFolder = 'DocumentActions/Reporting'
        localDocumentFile = 'ReportTemplate.docx'
        localDataFile = open(os.path.join(self.local_test_folder, reportingFolder + '/ReportData.json')).read()
        requestReportEngineSettings = asposewordscloud.ReportEngineSettings(data_source_type='Json', data_source_name='persons')
        request5 = asposewordscloud.models.requests.BuildReportOnlineRequest(
            template=open(os.path.join(self.local_test_folder, reportingFolder + '/' + localDocumentFile), 'rb'),
            data=localDataFile, report_engine_settings=requestReportEngineSettings)

        self.words_api.upload_file(request0)

        batch_request1 = asposewordscloud.models.requests.BatchRequest(request = request1)
        batch_request2 = asposewordscloud.models.requests.BatchRequest(request = request2)
        batch_request3 = asposewordscloud.models.requests.BatchRequest(request = request3)
        batch_request4 = asposewordscloud.models.requests.BatchRequest(request = request4)
        batch_request5 = asposewordscloud.models.requests.BatchRequest(request = request5)

        result = self.words_api.batch(batch_request1, batch_request2, batch_request3, batch_request4, batch_request5)
        self.assertEqual(len(result), 5)
        self.assertIsInstance(result[0], asposewordscloud.ParagraphLinkCollectionResponse)
        self.assertIsInstance(result[1], asposewordscloud.ParagraphResponse)
        self.assertIsInstance(result[2], asposewordscloud.ParagraphResponse)
        self.assertIsNone(result[3])
        self.assertIsInstance(result[4], bytes)

    #
    # Test for batch request without returning of intermediate results
    #
    def test_batch_without_intermidiate_results(self):
        filename = 'test_multi_pages.docx'
        remote_name = 'TestBatchParagraphs.docx'
        file = open(os.path.join(self.local_test_folder, self.local_common_folder, filename), 'rb')
        remote_path = os.path.join(self.remote_test_folder, self.test_folder, remote_name)
        remote_folder = os.path.join(self.remote_test_folder, self.test_folder)
        paragraph = asposewordscloud.models.ParagraphInsert(text="This is a new paragraph for your document")
        request0 = asposewordscloud.models.requests.UploadFileRequest(file, remote_path)
        request1 = asposewordscloud.models.requests.GetParagraphsRequest(name=remote_name, node_path="sections/0", folder=remote_folder)
        request2 = asposewordscloud.models.requests.GetParagraphRequest(name=remote_name, index=0, node_path="sections/0", folder=remote_folder)
        request3 = asposewordscloud.models.requests.InsertParagraphRequest(name=remote_name, paragraph=paragraph, node_path="sections/0", folder=remote_folder)
        request4 = asposewordscloud.models.requests.DeleteParagraphRequest(name=remote_name, index=0, node_path="", folder=remote_folder)

        reportingFolder = 'DocumentActions/Reporting'
        localDocumentFile = 'ReportTemplate.docx'
        localDataFile = open(os.path.join(self.local_test_folder, reportingFolder + '/ReportData.json')).read()
        requestReportEngineSettings = asposewordscloud.ReportEngineSettings(data_source_type='Json', data_source_name='persons')
        request5 = asposewordscloud.models.requests.BuildReportOnlineRequest(
            template=open(os.path.join(self.local_test_folder, reportingFolder + '/' + localDocumentFile), 'rb'),
            data=localDataFile, report_engine_settings=requestReportEngineSettings)

        self.words_api.upload_file(request0)

        batch_request1 = asposewordscloud.models.requests.BatchRequest(request = request1)
        batch_request2 = asposewordscloud.models.requests.BatchRequest(request = request2)
        batch_request3 = asposewordscloud.models.requests.BatchRequest(request = request3)
        batch_request4 = asposewordscloud.models.requests.BatchRequest(request = request4)
        batch_request5 = asposewordscloud.models.requests.BatchRequest(request = request5)

        result = self.words_api.batch_with_options(True, batch_request1, batch_request2, batch_request3, batch_request4, batch_request5)
        self.assertEqual(len(result), 1)
        self.assertIsInstance(result[0], bytes)

    #
    # Test for a batch with depend on feature
    #
    def test_batch_with_reversed_order(self):
        filename = 'test_multi_pages.docx'
        remote_name = 'test_batch_with_reversed_order.docx'
        file = open(os.path.join(self.local_test_folder, self.local_common_folder, filename), 'rb')
        remote_path = os.path.join(self.remote_test_folder, self.test_folder, remote_name)
        remote_folder = os.path.join(self.remote_test_folder, self.test_folder)

        self.upload_file(remote_folder + '/' + remote_name, file)

        request1 =  asposewordscloud.models.requests.GetParagraphsRequest(name=remote_name, node_path="sections/0", folder=remote_folder)
        request2 = asposewordscloud.models.requests.GetParagraphRequest(name=remote_name, index=0, node_path="sections/0", folder=remote_folder)

        batch_request1 = asposewordscloud.models.requests.BatchRequest(request=request1)
        batch_request2 = asposewordscloud.models.requests.BatchRequest(request=request2)
        batch_request1.depends_on(batch_request2)

        result = self.words_api.batch(batch_request1, batch_request2)
        self.assertEqual(len(result), 2)
        self.assertIsInstance(result[0], asposewordscloud.models.ParagraphResponse)
        self.assertIsInstance(result[1], asposewordscloud.models.ParagraphLinkCollectionResponse)


    #
    # Test for a batch with resultOf feature
    #
    def test_batch_with_result_of(self):
        filename = 'test_multi_pages.docx'
        remote_name = 'test_batch_with_result_of.docx'
        file = open(os.path.join(self.local_test_folder, self.local_common_folder, filename), 'rb')
        remote_path = os.path.join(self.remote_test_folder, self.test_folder, remote_name)
        remote_folder = os.path.join(self.remote_test_folder, self.test_folder)

        self.upload_file(remote_folder + '/' + remote_name, file)

        request1 =  asposewordscloud.models.requests.GetDocumentWithFormatRequest(name=remote_name, format='docx', folder=remote_folder)
        batch_request1 = asposewordscloud.models.requests.BatchRequest(request=request1)

        request2 = asposewordscloud.models.requests.DeleteCommentsOnlineRequest(document=batch_request1.use_as_source())
        batch_request2 = asposewordscloud.models.requests.BatchRequest(request=request2)

        batch_request2.depends_on(batch_request1)

        result = self.words_api.batch(batch_request1, batch_request2)
        self.assertEqual(len(result), 2)
        self.assertIsInstance(result[1], dict)